@@ -30,6 +30,7 @@ class TLSSecurity(str, Enum):
 class PropertyConfig(BaseModel):
     module_path: str
     module_name: str
+    validate_as_basemodel: bool = True
 
 
 class NodeConfig(BaseModel):
@@ -250,15 +251,16 @@ def build_validator_module_imports(db_config: DBConfig) -> str:
 def build_from_str_validator_str(node_config: T.Optional[NodeConfig]) -> str:
     if not node_config:
         return ""
-    field_names = node_config.basemodel_properties.keys()
-    if not field_names:
-        return ""
     field_name_strs: T.List[str] = []
-    for field_name in field_names:
+    for field_name, props_config in node_config.basemodel_properties.items():
+        if props_config.validate_as_basemodel is False:
+            continue
         key = field_name
         if field_name in node_config.appendix_properties:
             key += "_"
         field_name_strs.append(f'"{key}"')
+    if not field_name_strs:
+        return ""
     return f"""
 _from_str = validator({", ".join(field_name_strs)}, pre=True, allow_reuse=True)(from_str)
     """
