@@ -155,7 +155,7 @@ class Param(BaseModel):
     def type_str_basemodel(self, module_name: str) -> str:
         type_str = self.type_str
         if "[" in type_str:
-            type_str = re.sub(r"\[(\w+)\]", f"[{module_name}Model]", type_str)
+            type_str = re.sub(r"\[(\w+)\]", f"[{module_name}]", type_str)
         else:
             type_str = module_name
         return type_str
